@@ -20,10 +20,9 @@
  */
 
 #include "config.h"
-
 #include "empathy-dialpad-widget.h"
 
-#include <libempathy-gtk/empathy-dialpad-button.h>
+#include "empathy-dialpad-button.h"
 
 G_DEFINE_TYPE (EmpathyDialpadWidget, empathy_dialpad_widget, GTK_TYPE_BOX);
 
